import QtQuick 2.0
import Sailfish.Silica 1.0
import org.nemomobile.configuration 1.0

Page {
    id: page

	ConfigurationGroup {
        id: analogclockSettingsLandscape
        path: "/jolla-clock/analogclock/landscape"
        property int size: 240
		property int clocktopmargin: 60
		property int datetopmargin: 55
        property int dclocksize: 40
        property int dclocktopmargin: 10
		property int datesize: 30
		property bool digitalclock: true
		property bool weather: false
        property int lockScale: 80
		property int sneakScale: 90			
    }
	
    SilicaFlickable {
        anchors.fill: parent
        contentHeight: content.height
        interactive: contentHeight > height

        Column {
		    id: content
            width: parent.width
            spacing: Theme.paddingLarge

            PageHeader {
                title: qsTr("Settings for landscape orientation")
            }
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Clock and date sizes")
				
                content.sourceComponent: Column {
	                width: parent.width		
					
		            Slider {			
		                width: parent.width
		                label: qsTr("Clock size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 440 : 880
		                minimumValue: 200
		                stepSize: 10
		                value: analogclockSettingsLandscape.size
		                valueText: value + "x" + value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettingsLandscape.size = Math.round(value)
		                onPressAndHold: cancel()
		            }
					Slider {
		                width: parent.width
		                label: qsTr("Date text size")
		                maximumValue: Screen.sizeCategory < Screen.sizeLarge ? 100 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettingsLandscape.datesize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettingsLandscape.datesize = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Margins")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
					Slider {
		                width: parent.width
		                label: qsTr("Clock bottom margin")
		                maximumValue: 600
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -600
		                stepSize: 1
		                value: analogclockSettingsLandscape.clocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettingsLandscape.clocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
								
					Slider {
		                width: parent.width
		                label: qsTr("Date top margin")
		                maximumValue: 600
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -600
		                stepSize: 1
		                value: analogclockSettingsLandscape.datetopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettingsLandscape.datetopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}	
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Digital clock")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
					    id: dclockLandscape
		                width: parent.width
		                text: qsTr("Show digital clock")
		                checked: analogclockSettingsLandscape.digitalclock
		                onClicked: analogclockSettingsLandscape.digitalclock = checked
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettingsLandscape.digitalclock
		                label: qsTr("Digital clock size")
		                maximumValue: 120
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettingsLandscape.dclocksize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettingsLandscape.dclocksize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
						visible: analogclockSettingsLandscape.digitalclock
		                label: qsTr("Digital clock top margin")
		                maximumValue: 900
		                minimumValue: Screen.sizeCategory < Screen.Large ? 10 : -900
		                stepSize: 1
		                value: analogclockSettingsLandscape.dclocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettingsLandscape.dclocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Weather-widget")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show weather-widget")
		                checked: analogclockSettingsLandscape.weather
		                onClicked: analogclockSettingsLandscape.weather = checked
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettingsLandscape.weather
		                label: qsTr("Choose lockscreen widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettingsLandscape.lockScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettingsLandscape.lockScale = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettingsLandscape.weather
		                label: qsTr("Choose Sneak Peek widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettingsLandscape.sneakScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettingsLandscape.sneakScale = Math.round(value)
		                onPressAndHold: cancel()
		            }				
		        }
			}	
		}		
    }
}
