import QtQuick 2.0
import Sailfish.Silica 1.0
import org.nemomobile.configuration 1.0

Page {
    id: page

    ConfigurationGroup {
        id: analogclockSettings
        path: "/jolla-clock/analogclock"
        property int size: 320
		property int clocktopmargin: 130
		property int datetopmargin: 6
        property int face: 1	
        property int hourhandle: 1	
	    property int minutehandle: 1
		property bool digitalclock: false
        property int dclocksize: 100
        property int dclocktopmargin: 130
        property bool landscape: false
        property bool background: false
        property int opacity: 50
        property bool weather: false
        property int lockScale: 80
		property int sneakScale: 90		
        property int weekdaysize: 30
        property int shortdatesize: 50	
		//property bool alarmIndicators: false
		//property bool colored_alarmIndicators: false
		property bool forecast: false
		property bool launch_clock: false
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: content.height
        interactive: contentHeight > height
		
        PullDownMenu {
            MenuItem {
                text: qsTr("Settings for landscape orientation")
                onClicked: pageStack.push(Qt.resolvedUrl("landscape.qml"))
            }
        }
		
        Column {
		    id: content
            width: parent.width
            spacing: Theme.paddingLarge

            PageHeader {
			    //% "Analog clock settings"
                title: qsTrId("Analog clock settings")
            }

			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Clock face and handles")
				
                content.sourceComponent: Column {
	                width: parent.width
					
				    SectionHeader {
		                text: qsTr("Choose clock face")
		            }
								
		            Row {
		                id: clockfaceRow
		                width: parent.width
									
						Rectangle {
						    id: face1
						    color: (analogclockSettings.face == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.face = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: face2
						    color: (analogclockSettings.face == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.face = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: face3
						    color: (analogclockSettings.face == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.face = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: face4
						    color: (analogclockSettings.face == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.face = 4
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
		            }
					
				    SectionHeader {
		                text: qsTr("Choose hour handle")
		            }
					
		            Row {
		                id: hourhandleRow
		                width: parent.width
									
						Rectangle {
						    id: hourhandle1
						    color: (analogclockSettings.hourhandle == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.hourhandle = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: hourhandle2
						    color: (analogclockSettings.hourhandle == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.hourhandle = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: hourhandle3
						    color: (analogclockSettings.hourhandle == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.hourhandle = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: hourhandle4
						    color: (analogclockSettings.hourhandle == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.hourhandle = 4
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
		            }
					
				    SectionHeader {
		                text: qsTr("Choose minute handle")
		            }
					
		            Row {
		                id: minutehandleRow
		                width: parent.width
									
						Rectangle {
						    id: minutehandle1
						    color: (analogclockSettings.minutehandle == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.minutehandle = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: minutehandle2
						    color: (analogclockSettings.minutehandle == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.minutehandle = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: minutehandle3
						    color: (analogclockSettings.minutehandle == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.minutehandle = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: minutehandle4
						    color: (analogclockSettings.minutehandle == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.minutehandle = 4
								}
		                    }				
						}				
					}														
				}
            }
           			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Clock and date sizes")
				
                content.sourceComponent: Column {
	                width: parent.width			
			
		            Slider {
		                width: parent.width
		                label: qsTr("Clock size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 440 : 1000
		                minimumValue: 200
		                stepSize: 10
		                value: analogclockSettings.size
		                valueText: value + "x" + value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.size = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Weekday size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.weekdaysize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.weekdaysize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Month date size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.shortdatesize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.shortdatesize = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}	
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                //title: qsTr("Background and indicators")
				title: qsTr("Background and launching")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
	                width: parent.width
		                text: qsTr("Enable background")
		                checked: analogclockSettings.background
		                onClicked: analogclockSettings.background = checked
		            }
		
					Slider { 			   
		                width: parent.width
						visible: analogclockSettings.background
		                label: qsTr("Opacity")
		                maximumValue: 90
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.opacity
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.opacity = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            /*TextSwitch {
		                width: parent.width
		                text: qsTr("Enable alarm indicators")
		                checked: analogclockSettings.alarmIndicators
		                onClicked: analogclockSettings.alarmIndicators = checked
		            }*/
					
		            /*TextSwitch {
						visible: analogclockSettings.alarmIndicators
						description: qsTr("Enables different colors for alarm indicators like in Clock-app cover.")
		                width: parent.width
		                text: qsTr("Use colored indicators")
		                checked: analogclockSettings.colored_alarmIndicators
		                onClicked: analogclockSettings.colored_alarmIndicators = checked
		            }*/	
					
		            TextSwitch {
						description: qsTr("Enables clock launching by clicking on clock-face from lockscreen.")
		                width: parent.width
		                text: qsTr("Enable clock-launch from lockscreen")
		                checked: analogclockSettings.launch_clock
		                onClicked: analogclockSettings.launch_clock = checked
		            }						
				}
			}		
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Margins")
				
                content.sourceComponent: Column {
	                width: parent.width
					
					Slider {
		                width: parent.width
		                label: qsTr("Clock top margin")
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -800
		                stepSize: 1
		                value: analogclockSettings.clocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.clocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
		
					Slider {
		                width: parent.width
		                label: qsTr("Space between date and clock")
		                maximumValue: 600
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -800
		                stepSize: 1
		                value: analogclockSettings.datetopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.datetopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}	
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Weather-widget")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show weather-widget")
		                checked: analogclockSettings.weather
		                onClicked: analogclockSettings.weather = checked
		            }
			
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose lockscreen widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.lockScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.lockScale = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose Sneak Peek widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.sneakScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.sneakScale = Math.round(value)
		                onPressAndHold: cancel()
		            }	
					
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.weather
		                text: qsTr("Enable 5-days forecast")
						description: qsTr("It will show 5-day weather forecast on your lockscreen, click weather-widget to show or hide forecast.") + " " +
							qsTr("Please, hide forecast before disabling this option.")
		                checked: analogclockSettings.forecast
		                onClicked: analogclockSettings.forecast = checked
		            }					
				}	
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Digital clock")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show digital clock")
		                checked: analogclockSettings.digitalclock
		                onClicked: analogclockSettings.digitalclock = checked
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                label: qsTr("Digital clock size")
		                maximumValue: 120
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.dclocksize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.dclocksize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                label: qsTr("Digital clock top margin")
		                maximumValue: 900
		                minimumValue: Screen.sizeCategory < Screen.Large ? 10 : -800
		                stepSize: 1
		                value: analogclockSettings.dclocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.dclocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Separator {
                color: Theme.secondaryHighlightColor
                width: parent.width
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Qt.AlignHCenter
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Created by Ancelad in 0x7DF")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Big thanks to Ruslan Burkhanov for \nSVG-graphics :)")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
		    Label {
                text: qsTr("Donations are welcome :)")
                width: parent.width
				wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
            }

            Button {
                text: qsTr("Donate")
                width: 200
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                }
            }			
        }
    }
}
